@@ -51,37 +51,29 @@ psy_ds <- function(n, rule = 1, delta = 1) {
   }
 }
 
-lag_selection <- function(data, criterion = c("aic", "bic"), max_lag = 8) {
-  criterion <- match.arg(criterion)
-  tbl <- lag_selection_table(data, max_lag)
-  criterion_vec <- unname(tbl[,criterion])
-  min_idx <- which.min(criterion_vec)
-  as.integer(criterion_vec[min_idx])
-}
-
-lag_selection_table <- function(data, max_lag = 8) {
-  x <- parse_data(data)
-  nr <- nrow(x)
-  nc <- ncol(x)
-  snames <- series_names(x)
-  dof <- nr - max_lag - 2
-  min_criterion <- matrix(NA, nrow = nc, ncol = 2)
-  aic <- bic <- vector("numeric", max_lag + 1)
-  for (i in 1:nc) {
-    for (l in 0:max_lag) {
-      reg <- unroot(x, lag = l)
-      matx <- reg[,-1]
-      maty <- reg[, 1]
-      beta <- qr.solve(crossprod(matx)) %*% crossprod(matx, maty)
-      res <- maty - matx %*% beta
-      npdf <- sum(-1/2 * log(2 * pi) - 1/2 * (res^2))
-      aic[l + 1] <- -2 * npdf/nr + 2 * nrow(beta)/nr
-      bic[l + 1] <- -2 * npdf/nr + nrow(beta) * log(nr)/nr
-    }
-    min_criterion[i, 1] <- which.min(aic) - 1
-    min_criterion[i, 2] <- which.min(aic) - 1
-  }
-  dimnames(min_criterion) <- list(snames, c("aic", "bic"))
-  min_criterion
+#' Helper function to find `tb` from the Phillips and Shi (2020)
+#'
+#' This function helps to find the number of observations in the window
+#' over which size is to be controlled.
+#'
+#' @inheritParams radf_mc_cv
+#' @param freq The type of date-interval.
+#' @param size The size to be controlled.
+#'
+#' @references Phillips, P. C., & Shi, S. (2020). Real time monitoring of
+#' asset markets: Bubbles and crises. In Handbook of Statistics (Vol. 42, pp. 61-80). Elsevier.
+#'
+#' @references Shi, S., Hurn, S., Phillips, P.C.B., 2018. Causal change detection in possibly
+#' integrated systems: Revisiting the money-income relationship.
+#'
+#' @export
+ps_tb <- function(n, freq = c("monthly", "quarterly", "annual", "weekly"), size = 2) {
+  if (!is_n(n)) n <- NROW(n)
+  minw <- psy_minw(n)
+  freq <- match.arg(freq)
+  assert_positive_int(size)
+  multi <- switch(freq, weekly = 52, monthly = 12, quarterly = 4, annual = 1)
+  tb <- size * multi
+  minw + tb - 1 # is it +1 or minus 1
 }
 
